@@ -33,7 +33,7 @@ urllib.request.install_opener(opener)
 
 
 
-logger = logging.getLogger('pyCue')
+logger = logging.getLogger()
 
 # definizione dei namespaces per parsare gli atom
 namespaces = { 'atom':'{http://www.w3.org/2005/Atom}',
