@@ -268,7 +268,7 @@ caratteriSpeciali =  {'&':'&#38;','<':'&lt;','>':'&gt;'}
 
 if __name__ == "__main__":
 
-        logger = logging.getLogger('pyAPICoreX')
+        logger = logging.getLogger()
         logger.debug('PRIMA DI SETTARE ENVIRONMENT')
         logger.debug('ENV : ')
         logger.debug(os.environ)
