@@ -23,7 +23,7 @@ import rsi_python_lib.pyCueContenType as CCType
 import rsi_python_lib.pyConfig as pyConfig
 import rsi_python_lib.pySettaVars as pySettaVars
 
-logger = logging.getLogger('pyTools')
+logger = logging.getLogger()
 
 def SettaEnvironment( debug ):
 
@@ -53,7 +53,7 @@ def SettaEnvironment( debug ):
 
         else:
                 logger.debug( 'variabile _rsi_env_ non trovata: setto ENV di STAG')
-		config = pyConfig.config('STAG')
+                config = pyConfig.config('STAG')
                 pySettaVars.sectionMapping = pySettaVars.sectionMapping_STAG
 
         if (debug):
