@@ -23,7 +23,7 @@ namespaces = { 'atom':'{http://www.w3.org/2005/Atom}',
 		#'': '{http://www.w3.org/1999/xhtml}',
 		'playout' : '{http://ns.vizrt.com/ardome/playout}' }
 
-logger = logging.getLogger('pyECE')
+logger = logging.getLogger()
 
 class xmlSitemapIndexParser(object):
 
@@ -812,7 +812,6 @@ class xmlPiccoloParser(object):
 
 	def prendiInfoDaEce( self ):
 
-		logger = logging.getLogger('pySub_ECE')
 		logger.debug(' ---------- INIT prendiInfoDaEce -------------- ')
 		result = {}
 		listaChannels = []
